==> rospell-2007.02.rc1.tar.gz: rospell-2007.02.rc1/src/rospell/progressbar.cpp <==
//*********************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//*********************************************************************

#include "progressbar.h"
#include <qradiobutton.h>
#include <qpushbutton.h>
#include <qprogressbar.h>
#include <qlayout.h>
#include <qmotifstyle.h>


ProgressBar::ProgressBar( QWidget *parent, const char *name )
    : QButtonGroup( 0, Horizontal, name, parent, name ), timer() {
	setMargin( 10 );
	
	QGridLayout* toplayout = new QGridLayout( layout(), 2, 2, 5);
	
	
	// Create the progressbar
	progress = new QProgressBar( 100, this );
	//    progress->setStyle( new QMotifStyle() );
	toplayout->addMultiCellWidget( progress, 1, 1, 0, 1 );
	
	// connect the timeout() SIGNAL of the progress-timer to a SLOT
	connect( &timer, SIGNAL( timeout() ), this, SLOT( slotTimeout() ) );
	setMinimumWidth( 300 );
}

void ProgressBar::start(int steps, bool notimeout) {
	progress->setTotalSteps(steps);
	progress->reset();
	if (notimeout) {
		timer.stop();
		return;
	}

	if (!timer.isActive())
		timer.start(200);
}

void ProgressBar::adjust(int step) {
	progress->setProgress(step);
}

void ProgressBar::slotTimeout() {
	int p = progress->progress();
	if ( p >= progress->totalSteps() )
		p = 0;
	
	progress->setProgress(++p);
}

==> rospell-2009.00-rc2.tar.gz: rospell-2009.00-rc2/src/rospell/progressbar.cpp <==
//*********************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//*********************************************************************

#include "progressbar.h"
#include "editor.h"
#include <qradiobutton.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qmotifstyle.h>

ProgressBar::ProgressBar( QWidget *parent, QString name )
#ifdef USING_QT3
    : Q3ButtonGroup( 0, Horizontal, name, parent, "buttons" ), timer() {
#else
    : Q3ButtonGroup( 0, Qt::Horizontal, name, parent, "buttons" ), timer() {
#endif
	setMargin( 10 );

	QGridLayout* toplayout = new QGridLayout( layout(), 2, 2, 5);


	// Create the progressbar
	progress = new Q3ProgressBar( 100, this );
	//    progress->setStyle( new QMotifStyle() );
	toplayout->addMultiCellWidget( progress, 1, 1, 0, 1 );

	// connect the timeout() SIGNAL of the progress-timer to a SLOT
	connect( &timer, SIGNAL( timeout() ), this, SLOT( slotTimeout() ) );
	setMinimumWidth( 300 );
}

void ProgressBar::start(int steps, bool notimeout) {
	progress->setTotalSteps(steps);
	progress->reset();
	if (notimeout) {
		timer.stop();
		return;
	}

	if (!timer.isActive())
		timer.start(200);
}

void ProgressBar::adjust(int step) {
	progress->setProgress(step);
}

void ProgressBar::slotTimeout() {
	int p = progress->progress();
	if ( p >= progress->totalSteps() )
		p = 0;

	progress->setProgress(++p);
}
